@@ -121,12 +121,12 @@ struct tslib_input {
 	int	max_slots;
 	int	nr;
 	int	pen_down;
-	short	mt;
 	int	last_fd;
-	short	no_pressure;
-	short	type_a;
+	int8_t	mt;
+	int8_t	no_pressure;
+	int8_t	type_a;
 
-	unsigned int	special_device; /* broken device we work around, see below */
+	uint16_t	special_device; /* broken device we work around, see below */
 };
 
 #ifndef BUS_USB
@@ -162,9 +162,9 @@ static int get_special_device(struct tslib_input *i)
 	if (id.bustype != BUS_USB)
 		return 0;
 
-	switch(id.vendor) {
+	switch (id.vendor) {
 	case USB_VID_EGALAX:
-		switch(id.product) {
+		switch (id.product) {
 		case 0x0001:
 		/* taken from galax-raw. is this correct? */
 		case 0x7200:
@@ -174,7 +174,7 @@ static int get_special_device(struct tslib_input *i)
 			 * but to the product ID, should *really* be handled
 			 * in the kernel! They have quirks over there.
 			 */
-			switch(id.version) {
+			switch (id.version) {
 			case 0x0112:
 				i->special_device = EGALAX_VERSION_112;
 				break;
@@ -293,8 +293,10 @@ static int check_fd(struct tslib_input *i)
 	    !(absbit[BIT_WORD(ABS_MT_SLOT)] & BIT_MASK(ABS_MT_SLOT)))
 		i->type_a = 1;
 
+	/* for multitouch type B, tracking id is enough for pen down/up. type A
+	 * has pen down/up through the list of (empty) SYN_MT_REPORT */
 	if (!(keybit[BIT_WORD(BTN_TOUCH)] & BIT_MASK(BTN_TOUCH) ||
-	      keybit[BIT_WORD(BTN_LEFT)] & BIT_MASK(BTN_LEFT)) && i->type_a != 1) {
+	      keybit[BIT_WORD(BTN_LEFT)] & BIT_MASK(BTN_LEFT)) && i->mt != 1) {
 		fprintf(stderr,
 			"tslib: Selected device is not a touchscreen (missing BTN_TOUCH or BTN_LEFT)\n");
 		return -1;
@@ -560,7 +562,7 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 			return -ENOMEM;
 
 		for (j = 0; j < nr; j++) {
-			i->buf[j] = malloc(max_slots *
+			i->buf[j] = calloc(max_slots,
 					   sizeof(struct ts_sample_mt));
 			if (!i->buf[j])
 				return -ENOMEM;
