@@ -48,8 +48,8 @@ struct median_context {
 	int				*withsamples_mt;
 	int				slots;
 	unsigned int			depth;
-	int32_t *			sorted;
-	uint32_t *			usorted;
+	int32_t				*sorted;
+	uint32_t			*usorted;
 };
 
 static int comp_int(const void *n1, const void *n2)
@@ -199,6 +199,9 @@ static int median_read_mt(struct tslib_module_info *inf,
 	int ret;
 	int i, j;
 
+	if (!inf->next->ops->read_mt)
+		return -ENOSYS;
+
 	ret = inf->next->ops->read_mt(inf->next, samp, max_slots, nr);
 	if (ret < 0)
 		return ret;
@@ -299,6 +302,7 @@ static int median_read_mt(struct tslib_module_info *inf,
 				memset(c->delay_mt[j],
 				       0,
 				       sizeof(struct ts_sample_mt) * c->size);
+
 				c->withsamples_mt[j] = 0;
 			#ifdef DEBUG
 				printf("MEDIAN: Pen Up\n");
@@ -312,6 +316,11 @@ static int median_read_mt(struct tslib_module_info *inf,
 				printf("MEDIAN: Pen Down\n");
 			#endif
 			}
+
+			if (cpress != 0 && c->withsamples_mt[j] <= c->size / 2) {
+				samp[i][j].valid = -1;
+				c->withsamples_mt[j]++;
+			}
 		}
 	}
 
@@ -380,11 +389,11 @@ static int median_depth(struct tslib_module_info *inf, char *str,
 	return 0;
 }
 
-static const struct tslib_vars raw_vars[] = {
+static const struct tslib_vars median_vars[] = {
 	{ "depth", (void *)1, median_depth },
 };
 
-#define NR_VARS (sizeof(raw_vars) / sizeof(raw_vars[0]))
+#define NR_VARS (sizeof(median_vars) / sizeof(median_vars[0]))
 
 TSAPI struct tslib_module_info *median_mod_init(__attribute__ ((unused)) struct tsdev *dev,
 						const char *params)
@@ -404,7 +413,7 @@ TSAPI struct tslib_module_info *median_mod_init(__attribute__ ((unused)) struct
 	c->sorted = NULL;
 	c->usorted = NULL;
 
-	if (tslib_parse_vars(&c->module, raw_vars, NR_VARS, params)) {
+	if (tslib_parse_vars(&c->module, median_vars, NR_VARS, params)) {
 		free(c);
 		return NULL;
 	}
