@@ -14,7 +14,9 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_LIBDL
 #include <dlfcn.h>
+#endif
 
 #include "tslib-private.h"
 
@@ -30,9 +32,15 @@ int ts_close(struct tsdev *ts)
 		next = info->next;
 
 		handle = info->handle;
-		info->ops->fini(info);
+
+		if (info->ops->fini)
+			info->ops->fini(info);
+		else
+			free(info);
+	#ifdef HAVE_LIBDL
 		if (handle)
 			dlclose(handle);
+	#endif
 
 		info = next;
 	}
