@@ -13,7 +13,6 @@
 #include "config.h"
 
 #include <stdio.h>
-#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -35,16 +34,17 @@ union multiptr {
 	uint32_t *p32;
 };
 
-static int con_fd, last_vt = -1;
+static int32_t con_fd, last_vt = -1;
 static struct fb_fix_screeninfo fix;
 static struct fb_var_screeninfo var;
 static unsigned char *fbuffer;
 static unsigned char **line_addr;
-static int fb_fd = 0;
-static int bytes_per_pixel;
+static int32_t fb_fd = 0;
+static int32_t bytes_per_pixel;
 static uint32_t transp_mask;
-static unsigned colormap [256];
+static uint32_t colormap[256];
 uint32_t xres, yres;
+int8_t rotation;
 
 static char *defaultfbdevice = "/dev/fb0";
 static char *defaultconsoledevice = "/dev/tty";
@@ -57,8 +57,8 @@ int open_framebuffer(void)
 {
 	struct vt_stat vts;
 	char vtname[VTNAME_LEN];
-	int fd, nr;
-	unsigned y, addr;
+	int32_t fd, nr;
+	uint32_t y, addr;
 
 	if ((fbdevice = getenv ("TSLIB_FBDEVICE")) == NULL)
 		fbdevice = defaultfbdevice;
@@ -134,8 +134,16 @@ int open_framebuffer(void)
 		close(fb_fd);
 		return -1;
 	}
-	xres = var.xres;
-	yres = var.yres;
+	if (rotation & 1) {
+		/* 1 or 3 */
+		y = var.yres;
+		yres = var.xres;
+		xres = y;
+	} else {
+		/* 0 or 2 */
+		xres = var.xres;
+		yres = var.yres;
+	}
 
 	fbuffer = mmap(NULL, fix.smem_len, PROT_READ | PROT_WRITE, MAP_FILE | MAP_SHARED, fb_fd, 0);
 	if (fbuffer == (unsigned char *)-1) {
@@ -162,7 +170,6 @@ void close_framebuffer(void)
 	munmap(fbuffer, fix.smem_len);
 	close(fb_fd);
 
-
 	if(strcmp(consoledevice,"none")!=0) {
 		if (ioctl(con_fd, KDSETMODE, KD_TEXT) < 0)
 			perror("KDSETMODE");
@@ -175,9 +182,13 @@ void close_framebuffer(void)
 	}
 
 	free (line_addr);
+
+	xres = 0;
+	yres = 0;
+	rotation = 0;
 }
 
-void put_cross(int x, int y, unsigned colidx)
+void put_cross(int32_t x, int32_t y, uint32_t colidx)
 {
 	line (x - 10, y, x - 2, y, colidx);
 	line (x + 2, y, x + 10, y, colidx);
@@ -201,9 +212,9 @@ void put_cross(int x, int y, unsigned colidx)
 #endif
 }
 
-static void put_char(int x, int y, int c, int colidx)
+static void put_char(int32_t x, int32_t y, int32_t c, int32_t colidx)
 {
-	int i,j,bits;
+	int32_t i,j,bits;
 
 	for (i = 0; i < font_vga_8x8.height; i++) {
 		bits = font_vga_8x8.data [font_vga_8x8.height * c + i];
@@ -213,33 +224,33 @@ static void put_char(int x, int y, int c, int colidx)
 	}
 }
 
-void put_string(int x, int y, char *s, unsigned colidx)
+void put_string(int32_t x, int32_t y, char *s, uint32_t colidx)
 {
-	int i;
+	int32_t i;
 	for (i = 0; *s; i++, x += font_vga_8x8.width, s++)
 		put_char (x, y, *s, colidx);
 }
 
-void put_string_center(int x, int y, char *s, unsigned colidx)
+void put_string_center(int32_t x, int32_t y, char *s, uint32_t colidx)
 {
 	size_t sl = strlen (s);
         put_string (x - (sl / 2) * font_vga_8x8.width,
                     y - font_vga_8x8.height / 2, s, colidx);
 }
 
-void setcolor(unsigned colidx, unsigned value)
+void setcolor(uint32_t colidx, uint32_t value)
 {
-	unsigned res;
-	unsigned short red, green, blue;
+	uint32_t res;
+	uint16_t red, green, blue;
 	struct fb_cmap cmap;
 
-#ifdef DEBUG
 	if (colidx > 255) {
+#ifdef DEBUG
 		fprintf (stderr, "WARNING: color index = %u, must be <256\n",
 			 colidx);
+#endif
 		return;
 	}
-#endif
 
 	switch (bytes_per_pixel) {
 	default:
@@ -271,7 +282,26 @@ void setcolor(unsigned colidx, unsigned value)
         colormap [colidx] = res;
 }
 
-static inline void __setpixel (union multiptr loc, unsigned xormode, unsigned color)
+static void __pixel_loc(int32_t x, int32_t y, union multiptr *loc)
+{
+	switch (rotation) {
+	case 0:
+	default:
+		loc->p8 = line_addr[y] + x * bytes_per_pixel;
+		break;
+	case 1:
+		loc->p8 = line_addr[x] + (yres - y - 1) * bytes_per_pixel;
+		break;
+	case 2:
+		loc->p8 = line_addr[yres - y - 1] + (xres - x - 1) * bytes_per_pixel;
+		break;
+	case 3:
+		loc->p8 = line_addr[xres - x - 1] + y * bytes_per_pixel;
+		break;
+	}
+}
+
+static inline void __setpixel (union multiptr loc, uint32_t xormode, uint32_t color)
 {
 	switch(bytes_per_pixel) {
 	case 1:
@@ -311,35 +341,35 @@ static inline void __setpixel (union multiptr loc, unsigned xormode, unsigned co
 	}
 }
 
-void pixel (int x, int y, unsigned colidx)
+void pixel (int32_t x, int32_t y, uint32_t colidx)
 {
-	unsigned xormode;
+	uint32_t xormode;
 	union multiptr loc;
 
-	if ((x < 0) || ((uint32_t)x >= var.xres_virtual) ||
-	    (y < 0) || ((uint32_t)y >= var.yres_virtual))
+	if ((x < 0) || ((uint32_t)x >= xres) ||
+	    (y < 0) || ((uint32_t)y >= yres))
 		return;
 
 	xormode = colidx & XORMODE;
 	colidx &= ~XORMODE;
 
-#ifdef DEBUG
 	if (colidx > 255) {
+#ifdef DEBUG
 		fprintf (stderr, "WARNING: color value = %u, must be <256\n",
 			 colidx);
+#endif
 		return;
 	}
-#endif
 
-	loc.p8 = line_addr [y] + x * bytes_per_pixel;
+	__pixel_loc(x, y, &loc);
 	__setpixel (loc, xormode, colormap [colidx]);
 }
 
-void line (int x1, int y1, int x2, int y2, unsigned colidx)
+void line (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
-	int tmp;
-	int dx = x2 - x1;
-	int dy = y2 - y1;
+	int32_t tmp;
+	int32_t dx = x2 - x1;
+	int32_t dy = y2 - y1;
 
 	if (abs (dx) < abs (dy)) {
 		if (y1 > y2) {
@@ -371,7 +401,7 @@ void line (int x1, int y1, int x2, int y2, unsigned colidx)
 	}
 }
 
-void rect (int x1, int y1, int x2, int y2, unsigned colidx)
+void rect (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
 	line (x1, y1, x2, y1, colidx);
 	line (x2, y1+1, x2, y2-1, colidx);
@@ -379,10 +409,10 @@ void rect (int x1, int y1, int x2, int y2, unsigned colidx)
 	line (x1, y2-1, x1, y1+1, colidx);
 }
 
-void fillrect (int x1, int y1, int x2, int y2, unsigned colidx)
+void fillrect (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
-	int tmp;
-	unsigned xormode;
+	int32_t tmp;
+	uint32_t xormode;
 	union multiptr loc;
 
 	/* Clipping and sanity checking */
@@ -415,20 +445,20 @@ void fillrect (int x1, int y1, int x2, int y2, unsigned colidx)
 	xormode = colidx & XORMODE;
 	colidx &= ~XORMODE;
 
-#ifdef DEBUG
 	if (colidx > 255) {
+#ifdef DEBUG
 		fprintf (stderr, "WARNING: color value = %u, must be <256\n",
 			 colidx);
+#endif
 		return;
 	}
-#endif
 
 	colidx = colormap [colidx];
 
 	for (; y1 <= y2; y1++) {
-		loc.p8 = line_addr [y1] + x1 * bytes_per_pixel;
 		for (tmp = x1; tmp <= x2; tmp++) {
-			__setpixel (loc, xormode, colidx);
+			__pixel_loc(x1, y1, &loc);
+			__setpixel(loc, xormode, colidx);
 			loc.p8 += bytes_per_pixel;
 		}
 	}
