@@ -13,12 +13,7 @@
 #ifndef _FBUTILS_H
 #define _FBUTILS_H
 
-#ifdef __FreeBSD__
-#include <sys/stdint.h>
-typedef uint32_t __u32;
-#else
-#include <asm/types.h>
-#endif
+#include <stdint.h>
 
 /* This constant, being ORed with the color index tells the library
  * to draw in exclusive-or mode (that is, drawing the same second time
@@ -26,7 +21,8 @@ typedef uint32_t __u32;
  */
 #define XORMODE	0x80000000
 
-extern __u32 xres, yres;
+extern uint32_t xres, yres;
+extern int8_t rotation;
 
 int open_framebuffer(void);
 void close_framebuffer(void);
