@@ -55,11 +55,18 @@
 
 static void usage(char **argv)
 {
-	printf("tslib " PACKAGE_VERSION "\n");
+	struct ts_lib_version_data *ver = ts_libversion();
+
+	printf("tslib %s (library 0x%X)\n", ver->package_version, ver->version_num);
 	printf("\n");
 	printf("Usage: %s [--raw] [--non-blocking] [-s samples] [-i <device>] [-j <slots>]\n", argv[0]);
 }
 
+static int errfn(const char *fmt, va_list ap)
+{
+	return vfprintf(stderr, fmt, ap);
+}
+
 int main(int argc, char **argv)
 {
 	struct tsdev *ts;
@@ -69,12 +76,16 @@ int main(int argc, char **argv)
 	struct input_absinfo slot;
 #endif
 	int32_t user_slots = 0;
-	unsigned short max_slots = 1;
+	int32_t max_slots = 1;
 	int ret, i, j;
 	int read_samples = 1;
 	short non_blocking = 0;
 	short raw = 0;
 
+#ifndef TSLIB_VERSION_MT /* < 1.10 */
+	printf("You are running an old version of tslib. Please upgrade.\n");
+#endif
+
 	while (1) {
 		const struct option long_options[] = {
 			{ "help",         no_argument,       NULL, 'h' },
@@ -127,7 +138,7 @@ int main(int argc, char **argv)
 
 		default:
 			usage(argv);
-			break;
+			return 0;
 		}
 
 		if (errno) {
@@ -147,6 +158,8 @@ int main(int argc, char **argv)
 		return errno;
 	}
 
+	ts_error_fn = errfn;
+
 #ifdef TS_HAVE_EVDEV
 	if (ioctl(ts_fd(ts), EVIOCGABS(ABS_MT_SLOT), &slot) < 0) {
 		perror("ioctl EVIOGABS");
