@@ -114,6 +114,10 @@ struct data_t {
 
 static void help(void)
 {
+	struct ts_lib_version_data *ver = ts_libversion();
+
+	printf("tslib %s (library 0x%X)\n", ver->package_version, ver->version_num);
+	printf("\n");
 	printf("Starts tslib instance listening to given event <device>, creates a virtual\n");
 	printf("input event device with given <name> using 'uinput', then continually reads\n");
 	printf("touch reports from tslib and replays them as touch events of protocol type B\n");
@@ -129,7 +133,7 @@ static void help(void)
 	printf("  -f, --fbdev         touchscreen's framebuffer device\n");
 	printf("  -s, --slots         override available concurrent touch contacts\n");
 	printf("\n");
-	printf("See the manpage for futher details.\n");
+	printf("See the manpage for further details.\n");
 }
 
 #define MAX_CODES_PER_SLOT 20
@@ -594,7 +598,8 @@ int main(int argc, char **argv)
 			break;
 
 		default:
-			break;
+			help();
+			return 0;
 		}
 
 		if (errno) {
